@@ -27,17 +27,19 @@
  */
 
 #include <QMaemo5InformationBox>
+#include <QMessageBox>
 #include <QMenuBar>
 
 #include "client.h"
 
 #include "ui_chatwindow.h"
 #include "groupwindow.h"
-#include "groupsubjectdialog.h"
+#include "groupinfowindow.h"
+#include "groupsubjectwindow.h"
 
 #include "Whatsapp/util/utilities.h"
 
-GroupWindow::GroupWindow(Group group, QWidget *parent) :
+GroupWindow::GroupWindow(Group *group, QWidget *parent) :
     ChatWindow(group,parent)
 {
     setOnlineText("Group");
@@ -46,15 +48,19 @@ GroupWindow::GroupWindow(Group group, QWidget *parent) :
     actionChangeSubject->setObjectName(QString::fromUtf8("actionChangeSubject"));
     actionChangeSubject->setText("Change Subject");
 
+    QAction *actionViewGroup = new QAction(this);
+    actionViewGroup->setObjectName(QString::fromUtf8("actionViewGroup"));
+    actionViewGroup->setText("Group Info");
+
     QAction *actionLeaveGroup = new QAction(this);
     actionLeaveGroup->setObjectName(QString::fromUtf8("actionLeaveGroup"));
     actionLeaveGroup->setText("Leave Group");
 
     QMenu *groupMenu = menuBar()->addMenu("&Group");
     groupMenu->addAction(actionChangeSubject);
+    groupMenu->addAction(actionViewGroup);
     groupMenu->addAction(actionLeaveGroup);
 
-    // ui->actionViewContact->setText("View Group");
     ui->chatMenu->removeAction(ui->actionViewContact);
 
     // Actions
@@ -65,30 +71,71 @@ GroupWindow::GroupWindow(Group group, QWidget *parent) :
     connect(actionLeaveGroup,SIGNAL(triggered()),
             this,SLOT(requestLeaveGroupAction()));
 
+    connect(actionViewGroup,SIGNAL(triggered()),
+            this,SLOT(viewGroup()));
+
 }
 
 void GroupWindow::changeSubjectAction()
 {
-    GroupSubjectDialog dialog(contact.name,this);
+    GroupSubjectWindow *groupSubjectWindow =
+            new GroupSubjectWindow((Group *) contact, this);
 
-    if (dialog.exec() == QDialog::Accepted)
-    {
-        QString newSubject = dialog.getSubject();
-        Utilities::logData("Subject change to: " + newSubject);
-        emit changeSubject(contact.jid,newSubject);
-    }
+    connect(groupSubjectWindow,SIGNAL(changeSubject(QString, QString)),
+            Client::mainWin,SLOT(sendSetGroupSubjectFromChat(QString,QString)));
+
+    groupSubjectWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
+    groupSubjectWindow->setAttribute(Qt::WA_DeleteOnClose);
+    groupSubjectWindow->setWindowFlags(groupSubjectWindow->windowFlags() | Qt::Window);
+
+    groupSubjectWindow->show();
 }
 
-void GroupWindow::setGroup(Group &group, bool notify)
+
+void GroupWindow::setGroup(Group *group, bool notify)
 {
     setContact(group);
 
-    if (notify && group.subjectOwner != Client::myJid)
-        QMaemo5InformationBox::information(this,group.subjectOwnerName + " changed the subject to " +
-                                           group.name);
+    if (notify && group->subjectOwner != Client::myJid)
+        QMaemo5InformationBox::information(this,
+                                           Utilities::removeEmoji(group->subjectOwnerName) +
+                                           " changed the subject to " +
+                                           group->name);
 }
 
 void GroupWindow::requestLeaveGroupAction()
 {
-    emit requestLeaveGroup(contact.jid);
+    QMessageBox msg(this);
+
+    msg.setText("Are you sure you want to leave this group?");
+    msg.setStandardButtons(QMessageBox::Yes | QMessageBox::Cancel);
+
+    if (msg.exec() == QMessageBox::Yes)
+    {
+        emit requestLeaveGroup(contact->jid);
+        close();
+    }
+}
+
+
+void GroupWindow::viewGroup()
+{
+    Group *group = (Group *) contact;
+
+    GroupInfoWindow *groupInfoWindow = new GroupInfoWindow(group, Client::roster, this);
+
+    emit photoRefresh(group->jid, group->photoId, false);
+    emit getParticipants(group->jid);
+
+    groupInfoWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
+    groupInfoWindow->setAttribute(Qt::WA_DeleteOnClose);
+    groupInfoWindow->setWindowFlags(groupInfoWindow->windowFlags() | Qt::Window);
+
+    groupInfoWindow->show();
+
+}
+
+void GroupWindow::groupError()
+{
+    QMaemo5InformationBox::information(this,"Can't send to this group, not a member");
 }
